# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ros_gz_interfaces/srv/set_entity_pose.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_pose__pb2
from make87_messages_ros2.rolling.ros_gz_interfaces.msg import entity_pb2 as make87__messages__ros2_dot_rolling_dot_ros__gz__interfaces_dot_msg_dot_entity__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHmake87_messages_ros2/rolling/ros_gz_interfaces/srv/set_entity_pose.proto\x12\x32make87_messages_ros2.rolling.ros_gz_interfaces.srv\x1a\x39make87_messages_ros2/rolling/geometry_msgs/msg/pose.proto\x1a?make87_messages_ros2/rolling/ros_gz_interfaces/msg/entity.proto\"\xa6\x01\n\x14SetEntityPoseRequest\x12J\n\x06\x65ntity\x18\x01 \x01(\x0b\x32:.make87_messages_ros2.rolling.ros_gz_interfaces.msg.Entity\x12\x42\n\x04pose\x18\x02 \x01(\x0b\x32\x34.make87_messages_ros2.rolling.geometry_msgs.msg.Pose\"(\n\x15SetEntityPoseResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ros_gz_interfaces.srv.set_entity_pose_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SETENTITYPOSEREQUEST']._serialized_start=253
  _globals['_SETENTITYPOSEREQUEST']._serialized_end=419
  _globals['_SETENTITYPOSERESPONSE']._serialized_start=421
  _globals['_SETENTITYPOSERESPONSE']._serialized_end=461
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.builtin_interfaces.msg import time_pb2 as _time_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Imu(_message.Message):
    __slots__ = ("header", "stamp", "temperature", "gyro_x", "gyro_y", "gyro_z", "accel_x", "accel_y", "accel_z")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    STAMP_FIELD_NUMBER: _ClassVar[int]
    TEMPERATURE_FIELD_NUMBER: _ClassVar[int]
    GYRO_X_FIELD_NUMBER: _ClassVar[int]
    GYRO_Y_FIELD_NUMBER: _ClassVar[int]
    GYRO_Z_FIELD_NUMBER: _ClassVar[int]
    ACCEL_X_FIELD_NUMBER: _ClassVar[int]
    ACCEL_Y_FIELD_NUMBER: _ClassVar[int]
    ACCEL_Z_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    stamp: _time_pb2.Time
    temperature: float
    gyro_x: float
    gyro_y: float
    gyro_z: float
    accel_x: float
    accel_y: float
    accel_z: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., stamp: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., temperature: _Optional[float] = ..., gyro_x: _Optional[float] = ..., gyro_y: _Optional[float] = ..., gyro_z: _Optional[float] = ..., accel_x: _Optional[float] = ..., accel_y: _Optional[float] = ..., accel_z: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rmf_task_msgs/msg/task_summary.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_jazzy_dot_builtin__interfaces_dot_msg_dot_time__pb2
from make87_messages_ros2.jazzy.rmf_task_msgs.msg import task_profile_pb2 as make87__messages__ros2_dot_jazzy_dot_rmf__task__msgs_dot_msg_dot_task__profile__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/jazzy/rmf_task_msgs/msg/task_summary.proto\x12,make87_messages_ros2.jazzy.rmf_task_msgs.msg\x1a<make87_messages_ros2/jazzy/builtin_interfaces/msg/time.proto\x1a?make87_messages_ros2/jazzy/rmf_task_msgs/msg/task_profile.proto\"\xa0\x03\n\x0bTaskSummary\x12\x12\n\nfleet_name\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\t\x12O\n\x0ctask_profile\x18\x03 \x01(\x0b\x32\x39.make87_messages_ros2.jazzy.rmf_task_msgs.msg.TaskProfile\x12\r\n\x05state\x18\x04 \x01(\r\x12\x0e\n\x06status\x18\x05 \x01(\t\x12P\n\x0fsubmission_time\x18\x06 \x01(\x0b\x32\x37.make87_messages_ros2.jazzy.builtin_interfaces.msg.Time\x12K\n\nstart_time\x18\x07 \x01(\x0b\x32\x37.make87_messages_ros2.jazzy.builtin_interfaces.msg.Time\x12I\n\x08\x65nd_time\x18\x08 \x01(\x0b\x32\x37.make87_messages_ros2.jazzy.builtin_interfaces.msg.Time\x12\x12\n\nrobot_name\x18\t \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rmf_task_msgs.msg.task_summary_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TASKSUMMARY']._serialized_start=241
  _globals['_TASKSUMMARY']._serialized_end=657
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class MonitoringCase(_message.Message):
    __slots__ = ("monitoring_case_number", "fields", "fields_valid")
    MONITORING_CASE_NUMBER_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FIELDS_VALID_FIELD_NUMBER: _ClassVar[int]
    monitoring_case_number: int
    fields: _containers.RepeatedScalarFieldContainer[int]
    fields_valid: _containers.RepeatedScalarFieldContainer[bool]
    def __init__(self, monitoring_case_number: _Optional[int] = ..., fields: _Optional[_Iterable[int]] = ..., fields_valid: _Optional[_Iterable[bool]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import quaternion_pb2 as _quaternion_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import vector3_pb2 as _vector3_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AttitudeTarget(_message.Message):
    __slots__ = ("header", "ros2_header", "type_mask", "orientation", "body_rate", "thrust")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    TYPE_MASK_FIELD_NUMBER: _ClassVar[int]
    ORIENTATION_FIELD_NUMBER: _ClassVar[int]
    BODY_RATE_FIELD_NUMBER: _ClassVar[int]
    THRUST_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    type_mask: int
    orientation: _quaternion_pb2.Quaternion
    body_rate: _vector3_pb2.Vector3
    thrust: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., type_mask: _Optional[int] = ..., orientation: _Optional[_Union[_quaternion_pb2.Quaternion, _Mapping]] = ..., body_rate: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ..., thrust: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/rcl_interfaces/srv/set_parameters.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.rcl_interfaces.msg import parameter_pb2 as make87__messages__ros2_dot_humble_dot_rcl__interfaces_dot_msg_dot_parameter__pb2
from make87_messages_ros2.humble.rcl_interfaces.msg import set_parameters_result_pb2 as make87__messages__ros2_dot_humble_dot_rcl__interfaces_dot_msg_dot_set__parameters__result__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCmake87_messages_ros2/humble/rcl_interfaces/srv/set_parameters.proto\x12.make87_messages_ros2.humble.rcl_interfaces.srv\x1a!make87_messages/core/header.proto\x1a>make87_messages_ros2/humble/rcl_interfaces/msg/parameter.proto\x1aJmake87_messages_ros2/humble/rcl_interfaces/msg/set_parameters_result.proto\"\x93\x01\n\x14SetParametersRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12M\n\nparameters\x18\x02 \x03(\x0b\x32\x39.make87_messages_ros2.humble.rcl_interfaces.msg.Parameter\"\x9b\x01\n\x15SetParametersResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12T\n\x07results\x18\x02 \x03(\x0b\x32\x43.make87_messages_ros2.humble.rcl_interfaces.msg.SetParametersResultb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.rcl_interfaces.srv.set_parameters_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SETPARAMETERSREQUEST']._serialized_start=295
  _globals['_SETPARAMETERSREQUEST']._serialized_end=442
  _globals['_SETPARAMETERSRESPONSE']._serialized_start=445
  _globals['_SETPARAMETERSRESPONSE']._serialized_end=600
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/webots_ros2_msgs/msg/camera_recognition_objects.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2
from make87_messages_ros2.rolling.webots_ros2_msgs.msg import camera_recognition_object_pb2 as make87__messages__ros2_dot_rolling_dot_webots__ros2__msgs_dot_msg_dot_camera__recognition__object__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nRmake87_messages_ros2/rolling/webots_ros2_msgs/msg/camera_recognition_objects.proto\x12\x31make87_messages_ros2.rolling.webots_ros2_msgs.msg\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\x1aQmake87_messages_ros2/rolling/webots_ros2_msgs/msg/camera_recognition_object.proto\"\xba\x01\n\x18\x43\x61meraRecognitionObjects\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12[\n\x07objects\x18\x02 \x03(\x0b\x32J.make87_messages_ros2.rolling.webots_ros2_msgs.msg.CameraRecognitionObjectb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.webots_ros2_msgs.msg.camera_recognition_objects_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_CAMERARECOGNITIONOBJECTS']._serialized_start=277
  _globals['_CAMERARECOGNITIONOBJECTS']._serialized_end=463
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class HingeJointVel(_message.Message):
    __slots__ = ("name", "ax")
    NAME_FIELD_NUMBER: _ClassVar[int]
    AX_FIELD_NUMBER: _ClassVar[int]
    name: str
    ax: float
    def __init__(self, name: _Optional[str] = ..., ax: _Optional[float] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_pb2 as _pose_pb2
from make87_messages_ros2.humble.octomap_msgs.msg import octomap_pb2 as _octomap_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class OctomapWithPose(_message.Message):
    __slots__ = ("header", "ros2_header", "origin", "octomap")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    ORIGIN_FIELD_NUMBER: _ClassVar[int]
    OCTOMAP_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    origin: _pose_pb2.Pose
    octomap: _octomap_pb2.Octomap
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., origin: _Optional[_Union[_pose_pb2.Pose, _Mapping]] = ..., octomap: _Optional[_Union[_octomap_pb2.Octomap, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/gazebo_msgs/srv/get_link_properties.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_pose__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDmake87_messages_ros2/jazzy/gazebo_msgs/srv/get_link_properties.proto\x12*make87_messages_ros2.jazzy.gazebo_msgs.srv\x1a\x37make87_messages_ros2/jazzy/geometry_msgs/msg/pose.proto\"-\n\x18GetLinkPropertiesRequest\x12\x11\n\tlink_name\x18\x01 \x01(\t\"\xf7\x01\n\x19GetLinkPropertiesResponse\x12?\n\x03\x63om\x18\x01 \x01(\x0b\x32\x32.make87_messages_ros2.jazzy.geometry_msgs.msg.Pose\x12\x14\n\x0cgravity_mode\x18\x02 \x01(\x08\x12\x0c\n\x04mass\x18\x03 \x01(\x01\x12\x0b\n\x03ixx\x18\x04 \x01(\x01\x12\x0b\n\x03ixy\x18\x05 \x01(\x01\x12\x0b\n\x03ixz\x18\x06 \x01(\x01\x12\x0b\n\x03iyy\x18\x07 \x01(\x01\x12\x0b\n\x03iyz\x18\x08 \x01(\x01\x12\x0b\n\x03izz\x18\t \x01(\x01\x12\x0f\n\x07success\x18\n \x01(\x08\x12\x16\n\x0estatus_message\x18\x0b \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.gazebo_msgs.srv.get_link_properties_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GETLINKPROPERTIESREQUEST']._serialized_start=173
  _globals['_GETLINKPROPERTIESREQUEST']._serialized_end=218
  _globals['_GETLINKPROPERTIESRESPONSE']._serialized_start=221
  _globals['_GETLINKPROPERTIESRESPONSE']._serialized_end=468
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/vimbax_camera_msgs/srv/feature_bool_get.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.vimbax_camera_msgs.msg import error_pb2 as make87__messages__ros2_dot_humble_dot_vimbax__camera__msgs_dot_msg_dot_error__pb2
from make87_messages_ros2.humble.vimbax_camera_msgs.msg import feature_module_pb2 as make87__messages__ros2_dot_humble_dot_vimbax__camera__msgs_dot_msg_dot_feature__module__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/humble/vimbax_camera_msgs/srv/feature_bool_get.proto\x12\x32make87_messages_ros2.humble.vimbax_camera_msgs.srv\x1a!make87_messages/core/header.proto\x1a>make87_messages_ros2/humble/vimbax_camera_msgs/msg/error.proto\x1aGmake87_messages_ros2/humble/vimbax_camera_msgs/msg/feature_module.proto\"\xb6\x01\n\x15\x46\x65\x61tureBoolGetRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x14\n\x0c\x66\x65\x61ture_name\x18\x02 \x01(\t\x12Y\n\x0e\x66\x65\x61ture_module\x18\x03 \x01(\x0b\x32\x41.make87_messages_ros2.humble.vimbax_camera_msgs.msg.FeatureModule\"\x9f\x01\n\x16\x46\x65\x61tureBoolGetResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\r\n\x05value\x18\x02 \x01(\x08\x12H\n\x05\x65rror\x18\x03 \x01(\x0b\x32\x39.make87_messages_ros2.humble.vimbax_camera_msgs.msg.Errorb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.vimbax_camera_msgs.srv.feature_bool_get_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_FEATUREBOOLGETREQUEST']._serialized_start=302
  _globals['_FEATUREBOOLGETREQUEST']._serialized_end=484
  _globals['_FEATUREBOOLGETRESPONSE']._serialized_start=487
  _globals['_FEATUREBOOLGETRESPONSE']._serialized_end=646
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.tuw_multi_robot_msgs.msg import station_pb2 as _station_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class StationManagerStationProtocolRequest(_message.Message):
    __slots__ = ("request", "station")
    REQUEST_FIELD_NUMBER: _ClassVar[int]
    STATION_FIELD_NUMBER: _ClassVar[int]
    request: str
    station: _station_pb2.Station
    def __init__(self, request: _Optional[str] = ..., station: _Optional[_Union[_station_pb2.Station, _Mapping]] = ...) -> None: ...

class StationManagerStationProtocolResponse(_message.Message):
    __slots__ = ("response",)
    RESPONSE_FIELD_NUMBER: _ClassVar[int]
    response: str
    def __init__(self, response: _Optional[str] = ...) -> None: ...



from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class UBXRxmSpartn(_message.Message):
    __slots__ = ("header", "version", "msg_used", "sub_type", "msg_type")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    MSG_USED_FIELD_NUMBER: _ClassVar[int]
    SUB_TYPE_FIELD_NUMBER: _ClassVar[int]
    MSG_TYPE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    version: int
    msg_used: int
    sub_type: int
    msg_type: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., version: _Optional[int] = ..., msg_used: _Optional[int] = ..., sub_type: _Optional[int] = ..., msg_type: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg import field_pb2 as _field_pb2
from make87_messages_ros2.jazzy.sick_safetyscanners2_interfaces.msg import monitoring_case_pb2 as _monitoring_case_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class FieldDataRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class FieldDataResponse(_message.Message):
    __slots__ = ("fields", "device_name", "monitoring_cases")
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    DEVICE_NAME_FIELD_NUMBER: _ClassVar[int]
    MONITORING_CASES_FIELD_NUMBER: _ClassVar[int]
    fields: _containers.RepeatedCompositeFieldContainer[_field_pb2.Field]
    device_name: str
    monitoring_cases: _containers.RepeatedCompositeFieldContainer[_monitoring_case_pb2.MonitoringCase]
    def __init__(self, fields: _Optional[_Iterable[_Union[_field_pb2.Field, _Mapping]]] = ..., device_name: _Optional[str] = ..., monitoring_cases: _Optional[_Iterable[_Union[_monitoring_case_pb2.MonitoringCase, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/type_description_interfaces/msg/individual_type_description.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.type_description_interfaces.msg import field_pb2 as make87__messages__ros2_dot_jazzy_dot_type__description__interfaces_dot_msg_dot_field__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\\make87_messages_ros2/jazzy/type_description_interfaces/msg/individual_type_description.proto\x12:make87_messages_ros2.jazzy.type_description_interfaces.msg\x1a\x46make87_messages_ros2/jazzy/type_description_interfaces/msg/field.proto\"\x81\x01\n\x19IndividualTypeDescription\x12\x11\n\ttype_name\x18\x01 \x01(\t\x12Q\n\x06\x66ields\x18\x02 \x03(\x0b\x32\x41.make87_messages_ros2.jazzy.type_description_interfaces.msg.Fieldb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.type_description_interfaces.msg.individual_type_description_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_INDIVIDUALTYPEDESCRIPTION']._serialized_start=229
  _globals['_INDIVIDUALTYPEDESCRIPTION']._serialized_end=358
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RosMsgType(_message.Message):
    __slots__ = ("header", "md5", "name", "definition", "stamped")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    MD5_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DEFINITION_FIELD_NUMBER: _ClassVar[int]
    STAMPED_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    md5: str
    name: str
    definition: str
    stamped: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., md5: _Optional[str] = ..., name: _Optional[str] = ..., definition: _Optional[str] = ..., stamped: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/tuw_multi_robot_msgs/msg/router_status.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/rolling/tuw_multi_robot_msgs/msg/router_status.proto\x12\x35make87_messages_ros2.rolling.tuw_multi_robot_msgs.msg\"\xd6\x01\n\x0cRouterStatus\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x16\n\x0emissing_robots\x18\x03 \x03(\t\x12\x10\n\x08\x64uration\x18\x04 \x01(\x05\x12\x1b\n\x13overall_path_length\x18\x05 \x01(\x05\x12\x1b\n\x13longest_path_length\x18\x06 \x01(\x05\x12#\n\x1bpriority_scheduling_attemps\x18\x07 \x01(\x05\x12 \n\x18speed_scheduling_attemps\x18\x08 \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.tuw_multi_robot_msgs.msg.router_status_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ROUTERSTATUS']._serialized_start=133
  _globals['_ROUTERSTATUS']._serialized_end=347
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class FileOpenRequest(_message.Message):
    __slots__ = ("header", "file_path", "mode")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    FILE_PATH_FIELD_NUMBER: _ClassVar[int]
    MODE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    file_path: str
    mode: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., file_path: _Optional[str] = ..., mode: _Optional[int] = ...) -> None: ...

class FileOpenResponse(_message.Message):
    __slots__ = ("header", "size", "success", "r_errno")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    R_ERRNO_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    size: int
    success: bool
    r_errno: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., size: _Optional[int] = ..., success: bool = ..., r_errno: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class HilActuatorControls(_message.Message):
    __slots__ = ("header", "controls", "mode", "flags")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    CONTROLS_FIELD_NUMBER: _ClassVar[int]
    MODE_FIELD_NUMBER: _ClassVar[int]
    FLAGS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    controls: _containers.RepeatedScalarFieldContainer[float]
    mode: int
    flags: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., controls: _Optional[_Iterable[float]] = ..., mode: _Optional[int] = ..., flags: _Optional[int] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class DerivedValues(_message.Message):
    __slots__ = ("multiplication_factor", "number_of_beams", "scan_time", "start_angle", "angular_beam_resolution", "interbeam_period")
    MULTIPLICATION_FACTOR_FIELD_NUMBER: _ClassVar[int]
    NUMBER_OF_BEAMS_FIELD_NUMBER: _ClassVar[int]
    SCAN_TIME_FIELD_NUMBER: _ClassVar[int]
    START_ANGLE_FIELD_NUMBER: _ClassVar[int]
    ANGULAR_BEAM_RESOLUTION_FIELD_NUMBER: _ClassVar[int]
    INTERBEAM_PERIOD_FIELD_NUMBER: _ClassVar[int]
    multiplication_factor: int
    number_of_beams: int
    scan_time: int
    start_angle: float
    angular_beam_resolution: float
    interbeam_period: int
    def __init__(self, multiplication_factor: _Optional[int] = ..., number_of_beams: _Optional[int] = ..., scan_time: _Optional[int] = ..., start_angle: _Optional[float] = ..., angular_beam_resolution: _Optional[float] = ..., interbeam_period: _Optional[int] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Schema(_message.Message):
    __slots__ = ("hash", "channel_name", "schema_text")
    HASH_FIELD_NUMBER: _ClassVar[int]
    CHANNEL_NAME_FIELD_NUMBER: _ClassVar[int]
    SCHEMA_TEXT_FIELD_NUMBER: _ClassVar[int]
    hash: int
    channel_name: str
    schema_text: str
    def __init__(self, hash: _Optional[int] = ..., channel_name: _Optional[str] = ..., schema_text: _Optional[str] = ...) -> None: ...



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RadioStatus(_message.Message):
    __slots__ = ("header", "rssi", "remrssi", "txbuf", "noise", "remnoise", "rxerrors", "fixed", "rssi_dbm", "remrssi_dbm")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    RSSI_FIELD_NUMBER: _ClassVar[int]
    REMRSSI_FIELD_NUMBER: _ClassVar[int]
    TXBUF_FIELD_NUMBER: _ClassVar[int]
    NOISE_FIELD_NUMBER: _ClassVar[int]
    REMNOISE_FIELD_NUMBER: _ClassVar[int]
    RXERRORS_FIELD_NUMBER: _ClassVar[int]
    FIXED_FIELD_NUMBER: _ClassVar[int]
    RSSI_DBM_FIELD_NUMBER: _ClassVar[int]
    REMRSSI_DBM_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    rssi: int
    remrssi: int
    txbuf: int
    noise: int
    remnoise: int
    rxerrors: int
    fixed: int
    rssi_dbm: float
    remrssi_dbm: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., rssi: _Optional[int] = ..., remrssi: _Optional[int] = ..., txbuf: _Optional[int] = ..., noise: _Optional[int] = ..., remnoise: _Optional[int] = ..., rxerrors: _Optional[int] = ..., fixed: _Optional[int] = ..., rssi_dbm: _Optional[float] = ..., remrssi_dbm: _Optional[float] = ...) -> None: ...



from make87_messages_ros2.jazzy.gazebo_msgs.msg import link_state_pb2 as _link_state_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SetLinkStateRequest(_message.Message):
    __slots__ = ("link_state",)
    LINK_STATE_FIELD_NUMBER: _ClassVar[int]
    link_state: _link_state_pb2.LinkState
    def __init__(self, link_state: _Optional[_Union[_link_state_pb2.LinkState, _Mapping]] = ...) -> None: ...

class SetLinkStateResponse(_message.Message):
    __slots__ = ("success", "status_message")
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    STATUS_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    success: bool
    status_message: str
    def __init__(self, success: bool = ..., status_message: _Optional[str] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ODEJointProperties(_message.Message):
    __slots__ = ("header", "damping", "hi_stop", "lo_stop", "erp", "cfm", "stop_erp", "stop_cfm", "fudge_factor", "fmax", "vel")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    DAMPING_FIELD_NUMBER: _ClassVar[int]
    HI_STOP_FIELD_NUMBER: _ClassVar[int]
    LO_STOP_FIELD_NUMBER: _ClassVar[int]
    ERP_FIELD_NUMBER: _ClassVar[int]
    CFM_FIELD_NUMBER: _ClassVar[int]
    STOP_ERP_FIELD_NUMBER: _ClassVar[int]
    STOP_CFM_FIELD_NUMBER: _ClassVar[int]
    FUDGE_FACTOR_FIELD_NUMBER: _ClassVar[int]
    FMAX_FIELD_NUMBER: _ClassVar[int]
    VEL_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    damping: _containers.RepeatedScalarFieldContainer[float]
    hi_stop: _containers.RepeatedScalarFieldContainer[float]
    lo_stop: _containers.RepeatedScalarFieldContainer[float]
    erp: _containers.RepeatedScalarFieldContainer[float]
    cfm: _containers.RepeatedScalarFieldContainer[float]
    stop_erp: _containers.RepeatedScalarFieldContainer[float]
    stop_cfm: _containers.RepeatedScalarFieldContainer[float]
    fudge_factor: _containers.RepeatedScalarFieldContainer[float]
    fmax: _containers.RepeatedScalarFieldContainer[float]
    vel: _containers.RepeatedScalarFieldContainer[float]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., damping: _Optional[_Iterable[float]] = ..., hi_stop: _Optional[_Iterable[float]] = ..., lo_stop: _Optional[_Iterable[float]] = ..., erp: _Optional[_Iterable[float]] = ..., cfm: _Optional[_Iterable[float]] = ..., stop_erp: _Optional[_Iterable[float]] = ..., stop_cfm: _Optional[_Iterable[float]] = ..., fudge_factor: _Optional[_Iterable[float]] = ..., fmax: _Optional[_Iterable[float]] = ..., vel: _Optional[_Iterable[float]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/webots_ros2_msgs/srv/set_string.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/humble/webots_ros2_msgs/srv/set_string.proto\x12\x30make87_messages_ros2.humble.webots_ros2_msgs.srv\x1a!make87_messages/core/header.proto\"O\n\x10SetStringRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\r\n\x05value\x18\x02 \x01(\t\"R\n\x11SetStringResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0f\n\x07success\x18\x02 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.webots_ros2_msgs.srv.set_string_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SETSTRINGREQUEST']._serialized_start=154
  _globals['_SETSTRINGREQUEST']._serialized_end=233
  _globals['_SETSTRINGRESPONSE']._serialized_start=235
  _globals['_SETSTRINGRESPONSE']._serialized_end=317
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import accel_with_covariance_pb2 as _accel_with_covariance_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_with_covariance_pb2 as _pose_with_covariance_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import twist_with_covariance_pb2 as _twist_with_covariance_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class KinematicState(_message.Message):
    __slots__ = ("header", "ros2_header", "child_frame_id", "pose_with_covariance", "twist_with_covariance", "accel_with_covariance")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    CHILD_FRAME_ID_FIELD_NUMBER: _ClassVar[int]
    POSE_WITH_COVARIANCE_FIELD_NUMBER: _ClassVar[int]
    TWIST_WITH_COVARIANCE_FIELD_NUMBER: _ClassVar[int]
    ACCEL_WITH_COVARIANCE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    child_frame_id: str
    pose_with_covariance: _pose_with_covariance_pb2.PoseWithCovariance
    twist_with_covariance: _twist_with_covariance_pb2.TwistWithCovariance
    accel_with_covariance: _accel_with_covariance_pb2.AccelWithCovariance
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., child_frame_id: _Optional[str] = ..., pose_with_covariance: _Optional[_Union[_pose_with_covariance_pb2.PoseWithCovariance, _Mapping]] = ..., twist_with_covariance: _Optional[_Union[_twist_with_covariance_pb2.TwistWithCovariance, _Mapping]] = ..., accel_with_covariance: _Optional[_Union[_accel_with_covariance_pb2.AccelWithCovariance, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rcl_interfaces/msg/parameter_descriptor.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.rcl_interfaces.msg import floating_point_range_pb2 as make87__messages__ros2_dot_rolling_dot_rcl__interfaces_dot_msg_dot_floating__point__range__pb2
from make87_messages_ros2.rolling.rcl_interfaces.msg import integer_range_pb2 as make87__messages__ros2_dot_rolling_dot_rcl__interfaces_dot_msg_dot_integer__range__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJmake87_messages_ros2/rolling/rcl_interfaces/msg/parameter_descriptor.proto\x12/make87_messages_ros2.rolling.rcl_interfaces.msg\x1aJmake87_messages_ros2/rolling/rcl_interfaces/msg/floating_point_range.proto\x1a\x43make87_messages_ros2/rolling/rcl_interfaces/msg/integer_range.proto\"\xca\x02\n\x13ParameterDescriptor\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\r\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x1e\n\x16\x61\x64\x64itional_constraints\x18\x04 \x01(\t\x12\x11\n\tread_only\x18\x05 \x01(\x08\x12\x16\n\x0e\x64ynamic_typing\x18\x06 \x01(\x08\x12\x61\n\x14\x66loating_point_range\x18\x07 \x03(\x0b\x32\x43.make87_messages_ros2.rolling.rcl_interfaces.msg.FloatingPointRange\x12T\n\rinteger_range\x18\x08 \x03(\x0b\x32=.make87_messages_ros2.rolling.rcl_interfaces.msg.IntegerRangeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rcl_interfaces.msg.parameter_descriptor_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_PARAMETERDESCRIPTOR']._serialized_start=273
  _globals['_PARAMETERDESCRIPTOR']._serialized_end=603
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.rtabmap_msgs.msg import node_pb2 as _node_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetNodeDataRequest(_message.Message):
    __slots__ = ("header", "ids", "images", "scan", "grid", "user_data")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    IDS_FIELD_NUMBER: _ClassVar[int]
    IMAGES_FIELD_NUMBER: _ClassVar[int]
    SCAN_FIELD_NUMBER: _ClassVar[int]
    GRID_FIELD_NUMBER: _ClassVar[int]
    USER_DATA_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ids: _containers.RepeatedScalarFieldContainer[int]
    images: bool
    scan: bool
    grid: bool
    user_data: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ids: _Optional[_Iterable[int]] = ..., images: bool = ..., scan: bool = ..., grid: bool = ..., user_data: bool = ...) -> None: ...

class GetNodeDataResponse(_message.Message):
    __slots__ = ("header", "data")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    data: _containers.RepeatedCompositeFieldContainer[_node_pb2.Node]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., data: _Optional[_Iterable[_Union[_node_pb2.Node, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SensorState(_message.Message):
    __slots__ = ("header", "time_stamp", "bumper", "wheel_drop", "cliff", "left_encoder", "right_encoder", "left_pwm", "right_pwm", "buttons", "charger", "battery", "bottom", "current", "over_current", "digital_input", "analog_input")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    TIME_STAMP_FIELD_NUMBER: _ClassVar[int]
    BUMPER_FIELD_NUMBER: _ClassVar[int]
    WHEEL_DROP_FIELD_NUMBER: _ClassVar[int]
    CLIFF_FIELD_NUMBER: _ClassVar[int]
    LEFT_ENCODER_FIELD_NUMBER: _ClassVar[int]
    RIGHT_ENCODER_FIELD_NUMBER: _ClassVar[int]
    LEFT_PWM_FIELD_NUMBER: _ClassVar[int]
    RIGHT_PWM_FIELD_NUMBER: _ClassVar[int]
    BUTTONS_FIELD_NUMBER: _ClassVar[int]
    CHARGER_FIELD_NUMBER: _ClassVar[int]
    BATTERY_FIELD_NUMBER: _ClassVar[int]
    BOTTOM_FIELD_NUMBER: _ClassVar[int]
    CURRENT_FIELD_NUMBER: _ClassVar[int]
    OVER_CURRENT_FIELD_NUMBER: _ClassVar[int]
    DIGITAL_INPUT_FIELD_NUMBER: _ClassVar[int]
    ANALOG_INPUT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    time_stamp: int
    bumper: int
    wheel_drop: int
    cliff: int
    left_encoder: int
    right_encoder: int
    left_pwm: int
    right_pwm: int
    buttons: int
    charger: int
    battery: int
    bottom: _containers.RepeatedScalarFieldContainer[int]
    current: _containers.RepeatedScalarFieldContainer[int]
    over_current: int
    digital_input: int
    analog_input: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., time_stamp: _Optional[int] = ..., bumper: _Optional[int] = ..., wheel_drop: _Optional[int] = ..., cliff: _Optional[int] = ..., left_encoder: _Optional[int] = ..., right_encoder: _Optional[int] = ..., left_pwm: _Optional[int] = ..., right_pwm: _Optional[int] = ..., buttons: _Optional[int] = ..., charger: _Optional[int] = ..., battery: _Optional[int] = ..., bottom: _Optional[_Iterable[int]] = ..., current: _Optional[_Iterable[int]] = ..., over_current: _Optional[int] = ..., digital_input: _Optional[int] = ..., analog_input: _Optional[_Iterable[int]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MeasxData(_message.Message):
    __slots__ = ("header", "gnss_id", "sv_id", "c_no", "mpath_indic", "doppler_ms", "doppler_hz", "whole_chips", "frac_chips", "code_phase", "int_code_phase", "pseu_range_rms_err")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    GNSS_ID_FIELD_NUMBER: _ClassVar[int]
    SV_ID_FIELD_NUMBER: _ClassVar[int]
    C_NO_FIELD_NUMBER: _ClassVar[int]
    MPATH_INDIC_FIELD_NUMBER: _ClassVar[int]
    DOPPLER_MS_FIELD_NUMBER: _ClassVar[int]
    DOPPLER_HZ_FIELD_NUMBER: _ClassVar[int]
    WHOLE_CHIPS_FIELD_NUMBER: _ClassVar[int]
    FRAC_CHIPS_FIELD_NUMBER: _ClassVar[int]
    CODE_PHASE_FIELD_NUMBER: _ClassVar[int]
    INT_CODE_PHASE_FIELD_NUMBER: _ClassVar[int]
    PSEU_RANGE_RMS_ERR_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    gnss_id: int
    sv_id: int
    c_no: int
    mpath_indic: int
    doppler_ms: int
    doppler_hz: int
    whole_chips: int
    frac_chips: int
    code_phase: int
    int_code_phase: int
    pseu_range_rms_err: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., gnss_id: _Optional[int] = ..., sv_id: _Optional[int] = ..., c_no: _Optional[int] = ..., mpath_indic: _Optional[int] = ..., doppler_ms: _Optional[int] = ..., doppler_hz: _Optional[int] = ..., whole_chips: _Optional[int] = ..., frac_chips: _Optional[int] = ..., code_phase: _Optional[int] = ..., int_code_phase: _Optional[int] = ..., pseu_range_rms_err: _Optional[int] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import point_pb2 as _point_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_with_covariance_stamped_pb2 as _pose_with_covariance_stamped_pb2
from make87_messages_ros2.humble.object_recognition_msgs.msg import object_type_pb2 as _object_type_pb2
from make87_messages_ros2.humble.sensor_msgs.msg import point_cloud2_pb2 as _point_cloud2_pb2
from make87_messages_ros2.humble.shape_msgs.msg import mesh_pb2 as _mesh_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RecognizedObject(_message.Message):
    __slots__ = ("header", "ros2_header", "type", "confidence", "point_clouds", "bounding_mesh", "bounding_contours", "pose")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    CONFIDENCE_FIELD_NUMBER: _ClassVar[int]
    POINT_CLOUDS_FIELD_NUMBER: _ClassVar[int]
    BOUNDING_MESH_FIELD_NUMBER: _ClassVar[int]
    BOUNDING_CONTOURS_FIELD_NUMBER: _ClassVar[int]
    POSE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    type: _object_type_pb2.ObjectType
    confidence: float
    point_clouds: _containers.RepeatedCompositeFieldContainer[_point_cloud2_pb2.PointCloud2]
    bounding_mesh: _mesh_pb2.Mesh
    bounding_contours: _containers.RepeatedCompositeFieldContainer[_point_pb2.Point]
    pose: _pose_with_covariance_stamped_pb2.PoseWithCovarianceStamped
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., type: _Optional[_Union[_object_type_pb2.ObjectType, _Mapping]] = ..., confidence: _Optional[float] = ..., point_clouds: _Optional[_Iterable[_Union[_point_cloud2_pb2.PointCloud2, _Mapping]]] = ..., bounding_mesh: _Optional[_Union[_mesh_pb2.Mesh, _Mapping]] = ..., bounding_contours: _Optional[_Iterable[_Union[_point_pb2.Point, _Mapping]]] = ..., pose: _Optional[_Union[_pose_with_covariance_stamped_pb2.PoseWithCovarianceStamped, _Mapping]] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class TestFloat32Array(_message.Message):
    __slots__ = ("data",)
    DATA_FIELD_NUMBER: _ClassVar[int]
    data: _containers.RepeatedScalarFieldContainer[float]
    def __init__(self, data: _Optional[_Iterable[float]] = ...) -> None: ...



from make87_messages_ros2.jazzy.radar_msgs.msg import radar_track_pb2 as _radar_track_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RadarTracks(_message.Message):
    __slots__ = ("header", "tracks")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    TRACKS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    tracks: _containers.RepeatedCompositeFieldContainer[_radar_track_pb2.RadarTrack]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., tracks: _Optional[_Iterable[_Union[_radar_track_pb2.RadarTrack, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.jazzy.autoware_v2x_msgs.msg import virtual_gate_area_status_pb2 as _virtual_gate_area_status_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class VirtualGateStatus(_message.Message):
    __slots__ = ("areas",)
    AREAS_FIELD_NUMBER: _ClassVar[int]
    areas: _containers.RepeatedCompositeFieldContainer[_virtual_gate_area_status_pb2.VirtualGateAreaStatus]
    def __init__(self, areas: _Optional[_Iterable[_Union[_virtual_gate_area_status_pb2.VirtualGateAreaStatus, _Mapping]]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from make87_messages_ros2.humble.ublox_ubx_msgs.msg import carr_soln_pb2 as _carr_soln_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class UBXNavRelPosNED(_message.Message):
    __slots__ = ("header", "ros2_header", "version", "ref_station_id", "itow", "rel_pos_n", "rel_pos_e", "rel_pos_d", "rel_pos_length", "rel_pos_heading", "rel_pos_hp_n", "rel_pos_hp_e", "rel_pos_hp_d", "rel_pos_hp_length", "acc_n", "acc_e", "acc_d", "acc_length", "acc_heading", "gnss_fix_ok", "diff_soln", "rel_pos_valid", "carr_soln", "is_moving", "ref_pos_miss", "ref_obs_miss", "rel_pos_heading_valid", "rel_pos_normalized")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    REF_STATION_ID_FIELD_NUMBER: _ClassVar[int]
    ITOW_FIELD_NUMBER: _ClassVar[int]
    REL_POS_N_FIELD_NUMBER: _ClassVar[int]
    REL_POS_E_FIELD_NUMBER: _ClassVar[int]
    REL_POS_D_FIELD_NUMBER: _ClassVar[int]
    REL_POS_LENGTH_FIELD_NUMBER: _ClassVar[int]
    REL_POS_HEADING_FIELD_NUMBER: _ClassVar[int]
    REL_POS_HP_N_FIELD_NUMBER: _ClassVar[int]
    REL_POS_HP_E_FIELD_NUMBER: _ClassVar[int]
    REL_POS_HP_D_FIELD_NUMBER: _ClassVar[int]
    REL_POS_HP_LENGTH_FIELD_NUMBER: _ClassVar[int]
    ACC_N_FIELD_NUMBER: _ClassVar[int]
    ACC_E_FIELD_NUMBER: _ClassVar[int]
    ACC_D_FIELD_NUMBER: _ClassVar[int]
    ACC_LENGTH_FIELD_NUMBER: _ClassVar[int]
    ACC_HEADING_FIELD_NUMBER: _ClassVar[int]
    GNSS_FIX_OK_FIELD_NUMBER: _ClassVar[int]
    DIFF_SOLN_FIELD_NUMBER: _ClassVar[int]
    REL_POS_VALID_FIELD_NUMBER: _ClassVar[int]
    CARR_SOLN_FIELD_NUMBER: _ClassVar[int]
    IS_MOVING_FIELD_NUMBER: _ClassVar[int]
    REF_POS_MISS_FIELD_NUMBER: _ClassVar[int]
    REF_OBS_MISS_FIELD_NUMBER: _ClassVar[int]
    REL_POS_HEADING_VALID_FIELD_NUMBER: _ClassVar[int]
    REL_POS_NORMALIZED_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    version: int
    ref_station_id: int
    itow: int
    rel_pos_n: int
    rel_pos_e: int
    rel_pos_d: int
    rel_pos_length: int
    rel_pos_heading: int
    rel_pos_hp_n: int
    rel_pos_hp_e: int
    rel_pos_hp_d: int
    rel_pos_hp_length: int
    acc_n: int
    acc_e: int
    acc_d: int
    acc_length: int
    acc_heading: int
    gnss_fix_ok: bool
    diff_soln: bool
    rel_pos_valid: bool
    carr_soln: _carr_soln_pb2.CarrSoln
    is_moving: bool
    ref_pos_miss: bool
    ref_obs_miss: bool
    rel_pos_heading_valid: bool
    rel_pos_normalized: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., version: _Optional[int] = ..., ref_station_id: _Optional[int] = ..., itow: _Optional[int] = ..., rel_pos_n: _Optional[int] = ..., rel_pos_e: _Optional[int] = ..., rel_pos_d: _Optional[int] = ..., rel_pos_length: _Optional[int] = ..., rel_pos_heading: _Optional[int] = ..., rel_pos_hp_n: _Optional[int] = ..., rel_pos_hp_e: _Optional[int] = ..., rel_pos_hp_d: _Optional[int] = ..., rel_pos_hp_length: _Optional[int] = ..., acc_n: _Optional[int] = ..., acc_e: _Optional[int] = ..., acc_d: _Optional[int] = ..., acc_length: _Optional[int] = ..., acc_heading: _Optional[int] = ..., gnss_fix_ok: bool = ..., diff_soln: bool = ..., rel_pos_valid: bool = ..., carr_soln: _Optional[_Union[_carr_soln_pb2.CarrSoln, _Mapping]] = ..., is_moving: bool = ..., ref_pos_miss: bool = ..., ref_obs_miss: bool = ..., rel_pos_heading_valid: bool = ..., rel_pos_normalized: bool = ...) -> None: ...



from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class EsrVehicle3(_message.Message):
    __slots__ = ("header", "long_accel_validity", "lat_accel_validity", "lat_accel", "long_accel", "radar_fov_lr", "radar_fov_mr", "auto_align_disable", "radar_height", "serv_align_type", "serv_align_enable", "aalign_avg_ctr_total", "auto_align_converged", "wheel_slip", "serv_align_updates_need", "angle_mounting_offset")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    LONG_ACCEL_VALIDITY_FIELD_NUMBER: _ClassVar[int]
    LAT_ACCEL_VALIDITY_FIELD_NUMBER: _ClassVar[int]
    LAT_ACCEL_FIELD_NUMBER: _ClassVar[int]
    LONG_ACCEL_FIELD_NUMBER: _ClassVar[int]
    RADAR_FOV_LR_FIELD_NUMBER: _ClassVar[int]
    RADAR_FOV_MR_FIELD_NUMBER: _ClassVar[int]
    AUTO_ALIGN_DISABLE_FIELD_NUMBER: _ClassVar[int]
    RADAR_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    SERV_ALIGN_TYPE_FIELD_NUMBER: _ClassVar[int]
    SERV_ALIGN_ENABLE_FIELD_NUMBER: _ClassVar[int]
    AALIGN_AVG_CTR_TOTAL_FIELD_NUMBER: _ClassVar[int]
    AUTO_ALIGN_CONVERGED_FIELD_NUMBER: _ClassVar[int]
    WHEEL_SLIP_FIELD_NUMBER: _ClassVar[int]
    SERV_ALIGN_UPDATES_NEED_FIELD_NUMBER: _ClassVar[int]
    ANGLE_MOUNTING_OFFSET_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    long_accel_validity: bool
    lat_accel_validity: bool
    lat_accel: float
    long_accel: float
    radar_fov_lr: int
    radar_fov_mr: int
    auto_align_disable: bool
    radar_height: int
    serv_align_type: bool
    serv_align_enable: bool
    aalign_avg_ctr_total: int
    auto_align_converged: bool
    wheel_slip: int
    serv_align_updates_need: int
    angle_mounting_offset: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., long_accel_validity: bool = ..., lat_accel_validity: bool = ..., lat_accel: _Optional[float] = ..., long_accel: _Optional[float] = ..., radar_fov_lr: _Optional[int] = ..., radar_fov_mr: _Optional[int] = ..., auto_align_disable: bool = ..., radar_height: _Optional[int] = ..., serv_align_type: bool = ..., serv_align_enable: bool = ..., aalign_avg_ctr_total: _Optional[int] = ..., auto_align_converged: bool = ..., wheel_slip: _Optional[int] = ..., serv_align_updates_need: _Optional[int] = ..., angle_mounting_offset: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/ur_msgs/msg/io_states.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.ur_msgs.msg import analog_pb2 as make87__messages__ros2_dot_humble_dot_ur__msgs_dot_msg_dot_analog__pb2
from make87_messages_ros2.humble.ur_msgs.msg import digital_pb2 as make87__messages__ros2_dot_humble_dot_ur__msgs_dot_msg_dot_digital__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7make87_messages_ros2/humble/ur_msgs/msg/io_states.proto\x12\'make87_messages_ros2.humble.ur_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x34make87_messages_ros2/humble/ur_msgs/msg/analog.proto\x1a\x35make87_messages_ros2/humble/ur_msgs/msg/digital.proto\"\xb1\x03\n\x08IOStates\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12K\n\x11\x64igital_in_states\x18\x02 \x03(\x0b\x32\x30.make87_messages_ros2.humble.ur_msgs.msg.Digital\x12L\n\x12\x64igital_out_states\x18\x03 \x03(\x0b\x32\x30.make87_messages_ros2.humble.ur_msgs.msg.Digital\x12\x45\n\x0b\x66lag_states\x18\x04 \x03(\x0b\x32\x30.make87_messages_ros2.humble.ur_msgs.msg.Digital\x12I\n\x10\x61nalog_in_states\x18\x05 \x03(\x0b\x32/.make87_messages_ros2.humble.ur_msgs.msg.Analog\x12J\n\x11\x61nalog_out_states\x18\x06 \x03(\x0b\x32/.make87_messages_ros2.humble.ur_msgs.msg.Analogb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.ur_msgs.msg.io_states_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_IOSTATES']._serialized_start=245
  _globals['_IOSTATES']._serialized_end=678
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.septentrio_gnss_driver.msg import meas_epoch_channel_type2_pb2 as _meas_epoch_channel_type2_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MeasEpochChannelType1(_message.Message):
    __slots__ = ("rx_channel", "type", "sv_id", "misc", "code_lsb", "doppler", "carrier_lsb", "carrier_msb", "cn0", "lock_time", "obs_info", "n2", "type2")
    RX_CHANNEL_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    SV_ID_FIELD_NUMBER: _ClassVar[int]
    MISC_FIELD_NUMBER: _ClassVar[int]
    CODE_LSB_FIELD_NUMBER: _ClassVar[int]
    DOPPLER_FIELD_NUMBER: _ClassVar[int]
    CARRIER_LSB_FIELD_NUMBER: _ClassVar[int]
    CARRIER_MSB_FIELD_NUMBER: _ClassVar[int]
    CN0_FIELD_NUMBER: _ClassVar[int]
    LOCK_TIME_FIELD_NUMBER: _ClassVar[int]
    OBS_INFO_FIELD_NUMBER: _ClassVar[int]
    N2_FIELD_NUMBER: _ClassVar[int]
    TYPE2_FIELD_NUMBER: _ClassVar[int]
    rx_channel: int
    type: int
    sv_id: int
    misc: int
    code_lsb: int
    doppler: int
    carrier_lsb: int
    carrier_msb: int
    cn0: int
    lock_time: int
    obs_info: int
    n2: int
    type2: _containers.RepeatedCompositeFieldContainer[_meas_epoch_channel_type2_pb2.MeasEpochChannelType2]
    def __init__(self, rx_channel: _Optional[int] = ..., type: _Optional[int] = ..., sv_id: _Optional[int] = ..., misc: _Optional[int] = ..., code_lsb: _Optional[int] = ..., doppler: _Optional[int] = ..., carrier_lsb: _Optional[int] = ..., carrier_msb: _Optional[int] = ..., cn0: _Optional[int] = ..., lock_time: _Optional[int] = ..., obs_info: _Optional[int] = ..., n2: _Optional[int] = ..., type2: _Optional[_Iterable[_Union[_meas_epoch_channel_type2_pb2.MeasEpochChannelType2, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ublox_msgs/msg/cfg_tmode3.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:make87_messages_ros2/jazzy/ublox_msgs/msg/cfg_tmode3.proto\x12)make87_messages_ros2.jazzy.ublox_msgs.msg\"\xbc\x02\n\tCfgTMODE3\x12\x0f\n\x07version\x18\x01 \x01(\r\x12\x11\n\treserved1\x18\x02 \x01(\r\x12\r\n\x05\x66lags\x18\x03 \x01(\r\x12\x15\n\recef_x_or_lat\x18\x04 \x01(\x05\x12\x15\n\recef_y_or_lon\x18\x05 \x01(\x05\x12\x15\n\recef_z_or_alt\x18\x06 \x01(\x05\x12\x18\n\x10\x65\x63\x65\x66_x_or_lat_hp\x18\x07 \x01(\x05\x12\x18\n\x10\x65\x63\x65\x66_y_or_lon_hp\x18\x08 \x01(\x05\x12\x18\n\x10\x65\x63\x65\x66_z_or_alt_hp\x18\t \x01(\x05\x12\x11\n\treserved2\x18\n \x01(\r\x12\x15\n\rfixed_pos_acc\x18\x0b \x01(\r\x12\x14\n\x0csvin_min_dur\x18\x0c \x01(\r\x12\x16\n\x0esvin_acc_limit\x18\r \x01(\r\x12\x11\n\treserved3\x18\x0e \x03(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ublox_msgs.msg.cfg_tmode3_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_CFGTMODE3']._serialized_start=106
  _globals['_CFGTMODE3']._serialized_end=422
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from make87_messages_ros2.humble.tuw_object_msgs.msg import object_with_covariance_pb2 as _object_with_covariance_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ObjectWithCovarianceStamped(_message.Message):
    __slots__ = ("header", "ros2_header", "object")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    OBJECT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    object: _object_with_covariance_pb2.ObjectWithCovariance
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., object: _Optional[_Union[_object_with_covariance_pb2.ObjectWithCovariance, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/dynamixel_sdk_custom_interfaces/srv/get_position.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nQmake87_messages_ros2/jazzy/dynamixel_sdk_custom_interfaces/srv/get_position.proto\x12>make87_messages_ros2.jazzy.dynamixel_sdk_custom_interfaces.srv\" \n\x12GetPositionRequest\x12\n\n\x02id\x18\x01 \x01(\r\"\'\n\x13GetPositionResponse\x12\x10\n\x08position\x18\x01 \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.dynamixel_sdk_custom_interfaces.srv.get_position_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GETPOSITIONREQUEST']._serialized_start=149
  _globals['_GETPOSITIONREQUEST']._serialized_end=181
  _globals['_GETPOSITIONRESPONSE']._serialized_start=183
  _globals['_GETPOSITIONRESPONSE']._serialized_end=222
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_pb2 as _pose_pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import vector3_pb2 as _vector3_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import color_rgba_pb2 as _color_rgba_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Light(_message.Message):
    __slots__ = ("header", "name", "type", "pose", "diffuse", "specular", "attenuation_constant", "attenuation_linear", "attenuation_quadratic", "direction", "range", "cast_shadows", "spot_inner_angle", "spot_outer_angle", "spot_falloff", "id", "parent_id", "intensity")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    POSE_FIELD_NUMBER: _ClassVar[int]
    DIFFUSE_FIELD_NUMBER: _ClassVar[int]
    SPECULAR_FIELD_NUMBER: _ClassVar[int]
    ATTENUATION_CONSTANT_FIELD_NUMBER: _ClassVar[int]
    ATTENUATION_LINEAR_FIELD_NUMBER: _ClassVar[int]
    ATTENUATION_QUADRATIC_FIELD_NUMBER: _ClassVar[int]
    DIRECTION_FIELD_NUMBER: _ClassVar[int]
    RANGE_FIELD_NUMBER: _ClassVar[int]
    CAST_SHADOWS_FIELD_NUMBER: _ClassVar[int]
    SPOT_INNER_ANGLE_FIELD_NUMBER: _ClassVar[int]
    SPOT_OUTER_ANGLE_FIELD_NUMBER: _ClassVar[int]
    SPOT_FALLOFF_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    PARENT_ID_FIELD_NUMBER: _ClassVar[int]
    INTENSITY_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    name: str
    type: int
    pose: _pose_pb2.Pose
    diffuse: _color_rgba_pb2.ColorRGBA
    specular: _color_rgba_pb2.ColorRGBA
    attenuation_constant: float
    attenuation_linear: float
    attenuation_quadratic: float
    direction: _vector3_pb2.Vector3
    range: float
    cast_shadows: bool
    spot_inner_angle: float
    spot_outer_angle: float
    spot_falloff: float
    id: int
    parent_id: int
    intensity: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., name: _Optional[str] = ..., type: _Optional[int] = ..., pose: _Optional[_Union[_pose_pb2.Pose, _Mapping]] = ..., diffuse: _Optional[_Union[_color_rgba_pb2.ColorRGBA, _Mapping]] = ..., specular: _Optional[_Union[_color_rgba_pb2.ColorRGBA, _Mapping]] = ..., attenuation_constant: _Optional[float] = ..., attenuation_linear: _Optional[float] = ..., attenuation_quadratic: _Optional[float] = ..., direction: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ..., range: _Optional[float] = ..., cast_shadows: bool = ..., spot_inner_angle: _Optional[float] = ..., spot_outer_angle: _Optional[float] = ..., spot_falloff: _Optional[float] = ..., id: _Optional[int] = ..., parent_id: _Optional[int] = ..., intensity: _Optional[float] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SigLogEvent(_message.Message):
    __slots__ = ("header", "time_elapsed", "detection_type", "event_type")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    TIME_ELAPSED_FIELD_NUMBER: _ClassVar[int]
    DETECTION_TYPE_FIELD_NUMBER: _ClassVar[int]
    EVENT_TYPE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    time_elapsed: int
    detection_type: int
    event_type: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., time_elapsed: _Optional[int] = ..., detection_type: _Optional[int] = ..., event_type: _Optional[int] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class StatisticsNames(_message.Message):
    __slots__ = ("header", "ros2_header", "names", "names_version")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    NAMES_FIELD_NUMBER: _ClassVar[int]
    NAMES_VERSION_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    names: _containers.RepeatedScalarFieldContainer[str]
    names_version: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., names: _Optional[_Iterable[str]] = ..., names_version: _Optional[int] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class IsProgramRunningRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class IsProgramRunningResponse(_message.Message):
    __slots__ = ("answer", "program_running", "success")
    ANSWER_FIELD_NUMBER: _ClassVar[int]
    PROGRAM_RUNNING_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    answer: str
    program_running: bool
    success: bool
    def __init__(self, answer: _Optional[str] = ..., program_running: bool = ..., success: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/moveit_msgs/msg/allowed_collision_matrix.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.moveit_msgs.msg import allowed_collision_entry_pb2 as make87__messages__ros2_dot_humble_dot_moveit__msgs_dot_msg_dot_allowed__collision__entry__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJmake87_messages_ros2/humble/moveit_msgs/msg/allowed_collision_matrix.proto\x12+make87_messages_ros2.humble.moveit_msgs.msg\x1a!make87_messages/core/header.proto\x1aImake87_messages_ros2/humble/moveit_msgs/msg/allowed_collision_entry.proto\"\xf0\x01\n\x16\x41llowedCollisionMatrix\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x13\n\x0b\x65ntry_names\x18\x02 \x03(\t\x12X\n\x0c\x65ntry_values\x18\x03 \x03(\x0b\x32\x42.make87_messages_ros2.humble.moveit_msgs.msg.AllowedCollisionEntry\x12\x1b\n\x13\x64\x65\x66\x61ult_entry_names\x18\x04 \x03(\t\x12\x1c\n\x14\x64\x65\x66\x61ult_entry_values\x18\x05 \x03(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.moveit_msgs.msg.allowed_collision_matrix_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ALLOWEDCOLLISIONMATRIX']._serialized_start=234
  _globals['_ALLOWEDCOLLISIONMATRIX']._serialized_end=474
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.smacc2_msgs.msg import smacc_event_pb2 as _smacc_event_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SmaccStateReactor(_message.Message):
    __slots__ = ("index", "type_name", "object_tag", "event_sources")
    INDEX_FIELD_NUMBER: _ClassVar[int]
    TYPE_NAME_FIELD_NUMBER: _ClassVar[int]
    OBJECT_TAG_FIELD_NUMBER: _ClassVar[int]
    EVENT_SOURCES_FIELD_NUMBER: _ClassVar[int]
    index: int
    type_name: str
    object_tag: str
    event_sources: _containers.RepeatedCompositeFieldContainer[_smacc_event_pb2.SmaccEvent]
    def __init__(self, index: _Optional[int] = ..., type_name: _Optional[str] = ..., object_tag: _Optional[str] = ..., event_sources: _Optional[_Iterable[_Union[_smacc_event_pb2.SmaccEvent, _Mapping]]] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class RxmRAWSV(_message.Message):
    __slots__ = ("cp_mes", "pr_mes", "do_mes", "sv", "mes_qi", "cno", "lli")
    CP_MES_FIELD_NUMBER: _ClassVar[int]
    PR_MES_FIELD_NUMBER: _ClassVar[int]
    DO_MES_FIELD_NUMBER: _ClassVar[int]
    SV_FIELD_NUMBER: _ClassVar[int]
    MES_QI_FIELD_NUMBER: _ClassVar[int]
    CNO_FIELD_NUMBER: _ClassVar[int]
    LLI_FIELD_NUMBER: _ClassVar[int]
    cp_mes: float
    pr_mes: float
    do_mes: float
    sv: int
    mes_qi: int
    cno: int
    lli: int
    def __init__(self, cp_mes: _Optional[float] = ..., pr_mes: _Optional[float] = ..., do_mes: _Optional[float] = ..., sv: _Optional[int] = ..., mes_qi: _Optional[int] = ..., cno: _Optional[int] = ..., lli: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/example_interfaces/srv/add_two_ints.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFmake87_messages_ros2/rolling/example_interfaces/srv/add_two_ints.proto\x12\x33make87_messages_ros2.rolling.example_interfaces.srv\")\n\x11\x41\x64\x64TwoIntsRequest\x12\t\n\x01\x61\x18\x01 \x01(\x03\x12\t\n\x01\x62\x18\x02 \x01(\x03\"!\n\x12\x41\x64\x64TwoIntsResponse\x12\x0b\n\x03sum\x18\x01 \x01(\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.example_interfaces.srv.add_two_ints_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ADDTWOINTSREQUEST']._serialized_start=127
  _globals['_ADDTWOINTSREQUEST']._serialized_end=168
  _globals['_ADDTWOINTSRESPONSE']._serialized_start=170
  _globals['_ADDTWOINTSRESPONSE']._serialized_end=203
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.rmf_task_msgs.msg import bid_proposal_pb2 as _bid_proposal_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class BidResponse(_message.Message):
    __slots__ = ("task_id", "has_proposal", "proposal", "errors")
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    HAS_PROPOSAL_FIELD_NUMBER: _ClassVar[int]
    PROPOSAL_FIELD_NUMBER: _ClassVar[int]
    ERRORS_FIELD_NUMBER: _ClassVar[int]
    task_id: str
    has_proposal: bool
    proposal: _bid_proposal_pb2.BidProposal
    errors: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, task_id: _Optional[str] = ..., has_proposal: bool = ..., proposal: _Optional[_Union[_bid_proposal_pb2.BidProposal, _Mapping]] = ..., errors: _Optional[_Iterable[str]] = ...) -> None: ...



from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ESCInfoItem(_message.Message):
    __slots__ = ("header", "failure_flags", "error_count", "temperature")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    FAILURE_FLAGS_FIELD_NUMBER: _ClassVar[int]
    ERROR_COUNT_FIELD_NUMBER: _ClassVar[int]
    TEMPERATURE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    failure_flags: int
    error_count: int
    temperature: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., failure_flags: _Optional[int] = ..., error_count: _Optional[int] = ..., temperature: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/mavros_msgs/srv/command_trigger_interval.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKmake87_messages_ros2/rolling/mavros_msgs/srv/command_trigger_interval.proto\x12,make87_messages_ros2.rolling.mavros_msgs.srv\"M\n\x1d\x43ommandTriggerIntervalRequest\x12\x12\n\ncycle_time\x18\x01 \x01(\x02\x12\x18\n\x10integration_time\x18\x02 \x01(\x02\"A\n\x1e\x43ommandTriggerIntervalResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0e\n\x06result\x18\x02 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.mavros_msgs.srv.command_trigger_interval_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_COMMANDTRIGGERINTERVALREQUEST']._serialized_start=125
  _globals['_COMMANDTRIGGERINTERVALREQUEST']._serialized_end=202
  _globals['_COMMANDTRIGGERINTERVALRESPONSE']._serialized_start=204
  _globals['_COMMANDTRIGGERINTERVALRESPONSE']._serialized_end=269
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.builtin_interfaces.msg import duration_pb2 as _duration_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import point_pb2 as _point_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_pb2 as _pose_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import vector3_pb2 as _vector3_pb2
from make87_messages_ros2.humble.sensor_msgs.msg import compressed_image_pb2 as _compressed_image_pb2
from make87_messages_ros2.humble.std_msgs.msg import color_rgba_pb2 as _color_rgba_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from make87_messages_ros2.humble.visualization_msgs.msg import mesh_file_pb2 as _mesh_file_pb2
from make87_messages_ros2.humble.visualization_msgs.msg import uv_coordinate_pb2 as _uv_coordinate_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Marker(_message.Message):
    __slots__ = ("header", "ros2_header", "ns", "id", "type", "action", "pose", "scale", "color", "lifetime", "frame_locked", "points", "colors", "texture_resource", "texture", "uv_coordinates", "text", "mesh_resource", "mesh_file", "mesh_use_embedded_materials")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    NS_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    ACTION_FIELD_NUMBER: _ClassVar[int]
    POSE_FIELD_NUMBER: _ClassVar[int]
    SCALE_FIELD_NUMBER: _ClassVar[int]
    COLOR_FIELD_NUMBER: _ClassVar[int]
    LIFETIME_FIELD_NUMBER: _ClassVar[int]
    FRAME_LOCKED_FIELD_NUMBER: _ClassVar[int]
    POINTS_FIELD_NUMBER: _ClassVar[int]
    COLORS_FIELD_NUMBER: _ClassVar[int]
    TEXTURE_RESOURCE_FIELD_NUMBER: _ClassVar[int]
    TEXTURE_FIELD_NUMBER: _ClassVar[int]
    UV_COORDINATES_FIELD_NUMBER: _ClassVar[int]
    TEXT_FIELD_NUMBER: _ClassVar[int]
    MESH_RESOURCE_FIELD_NUMBER: _ClassVar[int]
    MESH_FILE_FIELD_NUMBER: _ClassVar[int]
    MESH_USE_EMBEDDED_MATERIALS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    ns: str
    id: int
    type: int
    action: int
    pose: _pose_pb2.Pose
    scale: _vector3_pb2.Vector3
    color: _color_rgba_pb2.ColorRGBA
    lifetime: _duration_pb2.Duration
    frame_locked: bool
    points: _containers.RepeatedCompositeFieldContainer[_point_pb2.Point]
    colors: _containers.RepeatedCompositeFieldContainer[_color_rgba_pb2.ColorRGBA]
    texture_resource: str
    texture: _compressed_image_pb2.CompressedImage
    uv_coordinates: _containers.RepeatedCompositeFieldContainer[_uv_coordinate_pb2.UVCoordinate]
    text: str
    mesh_resource: str
    mesh_file: _mesh_file_pb2.MeshFile
    mesh_use_embedded_materials: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., ns: _Optional[str] = ..., id: _Optional[int] = ..., type: _Optional[int] = ..., action: _Optional[int] = ..., pose: _Optional[_Union[_pose_pb2.Pose, _Mapping]] = ..., scale: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ..., color: _Optional[_Union[_color_rgba_pb2.ColorRGBA, _Mapping]] = ..., lifetime: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., frame_locked: bool = ..., points: _Optional[_Iterable[_Union[_point_pb2.Point, _Mapping]]] = ..., colors: _Optional[_Iterable[_Union[_color_rgba_pb2.ColorRGBA, _Mapping]]] = ..., texture_resource: _Optional[str] = ..., texture: _Optional[_Union[_compressed_image_pb2.CompressedImage, _Mapping]] = ..., uv_coordinates: _Optional[_Iterable[_Union[_uv_coordinate_pb2.UVCoordinate, _Mapping]]] = ..., text: _Optional[str] = ..., mesh_resource: _Optional[str] = ..., mesh_file: _Optional[_Union[_mesh_file_pb2.MeshFile, _Mapping]] = ..., mesh_use_embedded_materials: bool = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import vector3_pb2 as _vector3_pb2
from make87_messages_ros2.humble.sbg_driver.msg import sbg_ekf_status_pb2 as _sbg_ekf_status_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SbgEkfVelBody(_message.Message):
    __slots__ = ("header", "ros2_header", "time_stamp", "velocity", "velocity_accuracy", "status")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    TIME_STAMP_FIELD_NUMBER: _ClassVar[int]
    VELOCITY_FIELD_NUMBER: _ClassVar[int]
    VELOCITY_ACCURACY_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    time_stamp: int
    velocity: _vector3_pb2.Vector3
    velocity_accuracy: _vector3_pb2.Vector3
    status: _sbg_ekf_status_pb2.SbgEkfStatus
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., time_stamp: _Optional[int] = ..., velocity: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ..., velocity_accuracy: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ..., status: _Optional[_Union[_sbg_ekf_status_pb2.SbgEkfStatus, _Mapping]] = ...) -> None: ...



from make87_messages_ros2.rolling.cartographer_ros_msgs.msg import status_response_pb2 as _status_response_pb2
from make87_messages_ros2.rolling.cartographer_ros_msgs.msg import trajectory_states_pb2 as _trajectory_states_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetTrajectoryStatesRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetTrajectoryStatesResponse(_message.Message):
    __slots__ = ("status", "trajectory_states")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    TRAJECTORY_STATES_FIELD_NUMBER: _ClassVar[int]
    status: _status_response_pb2.StatusResponse
    trajectory_states: _trajectory_states_pb2.TrajectoryStates
    def __init__(self, status: _Optional[_Union[_status_response_pb2.StatusResponse, _Mapping]] = ..., trajectory_states: _Optional[_Union[_trajectory_states_pb2.TrajectoryStates, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/rtabmap_msgs/srv/global_bundle_adjustment.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKmake87_messages_ros2/humble/rtabmap_msgs/srv/global_bundle_adjustment.proto\x12,make87_messages_ros2.humble.rtabmap_msgs.srv\x1a!make87_messages/core/header.proto\"\x9c\x01\n\x1dGlobalBundleAdjustmentRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0c\n\x04type\x18\x02 \x01(\x05\x12\x12\n\niterations\x18\x03 \x01(\x05\x12\x16\n\x0epixel_variance\x18\x04 \x01(\x02\x12\x13\n\x0bvoc_matches\x18\x05 \x01(\x08\"N\n\x1eGlobalBundleAdjustmentResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Headerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.rtabmap_msgs.srv.global_bundle_adjustment_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GLOBALBUNDLEADJUSTMENTREQUEST']._serialized_start=161
  _globals['_GLOBALBUNDLEADJUSTMENTREQUEST']._serialized_end=317
  _globals['_GLOBALBUNDLEADJUSTMENTRESPONSE']._serialized_start=319
  _globals['_GLOBALBUNDLEADJUSTMENTRESPONSE']._serialized_end=397
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.builtin_interfaces.msg import time_pb2 as _time_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ControlModeCommandRequest(_message.Message):
    __slots__ = ("stamp", "mode")
    STAMP_FIELD_NUMBER: _ClassVar[int]
    MODE_FIELD_NUMBER: _ClassVar[int]
    stamp: _time_pb2.Time
    mode: int
    def __init__(self, stamp: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., mode: _Optional[int] = ...) -> None: ...

class ControlModeCommandResponse(_message.Message):
    __slots__ = ("success",)
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    success: bool
    def __init__(self, success: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/micro_ros_msgs/msg/graph.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.micro_ros_msgs.msg import node_pb2 as make87__messages__ros2_dot_rolling_dot_micro__ros__msgs_dot_msg_dot_node__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;make87_messages_ros2/rolling/micro_ros_msgs/msg/graph.proto\x12/make87_messages_ros2.rolling.micro_ros_msgs.msg\x1a:make87_messages_ros2/rolling/micro_ros_msgs/msg/node.proto\"M\n\x05Graph\x12\x44\n\x05nodes\x18\x01 \x03(\x0b\x32\x35.make87_messages_ros2.rolling.micro_ros_msgs.msg.Nodeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.micro_ros_msgs.msg.graph_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GRAPH']._serialized_start=172
  _globals['_GRAPH']._serialized_end=249
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/turtlebot4_msgs/msg/user_display.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/jazzy/turtlebot4_msgs/msg/user_display.proto\x12.make87_messages_ros2.jazzy.turtlebot4_msgs.msg\"S\n\x0bUserDisplay\x12\n\n\x02ip\x18\x01 \x01(\t\x12\x0f\n\x07\x62\x61ttery\x18\x02 \x01(\t\x12\x0f\n\x07\x65ntries\x18\x03 \x03(\t\x12\x16\n\x0eselected_entry\x18\x04 \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.turtlebot4_msgs.msg.user_display_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_USERDISPLAY']._serialized_start=117
  _globals['_USERDISPLAY']._serialized_end=200
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class EsrValid1(_message.Message):
    __slots__ = ("header", "ros2_header", "canmsg", "lr_sn", "lr_range", "lr_range_rate", "lr_angle", "lr_power")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    CANMSG_FIELD_NUMBER: _ClassVar[int]
    LR_SN_FIELD_NUMBER: _ClassVar[int]
    LR_RANGE_FIELD_NUMBER: _ClassVar[int]
    LR_RANGE_RATE_FIELD_NUMBER: _ClassVar[int]
    LR_ANGLE_FIELD_NUMBER: _ClassVar[int]
    LR_POWER_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    canmsg: str
    lr_sn: int
    lr_range: float
    lr_range_rate: float
    lr_angle: float
    lr_power: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., canmsg: _Optional[str] = ..., lr_sn: _Optional[int] = ..., lr_range: _Optional[float] = ..., lr_range_rate: _Optional[float] = ..., lr_angle: _Optional[float] = ..., lr_power: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.rolling.geometry_msgs.msg import polygon_pb2 as _polygon_pb2
from make87_messages_ros2.rolling.geometry_msgs.msg import vector3_pb2 as _vector3_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Shape(_message.Message):
    __slots__ = ("type", "footprint", "dimensions")
    TYPE_FIELD_NUMBER: _ClassVar[int]
    FOOTPRINT_FIELD_NUMBER: _ClassVar[int]
    DIMENSIONS_FIELD_NUMBER: _ClassVar[int]
    type: int
    footprint: _polygon_pb2.Polygon
    dimensions: _vector3_pb2.Vector3
    def __init__(self, type: _Optional[int] = ..., footprint: _Optional[_Union[_polygon_pb2.Polygon, _Mapping]] = ..., dimensions: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/sick_scan_xd/msg/radar_pre_header.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.sick_scan_xd.msg import radar_pre_header_device_block_pb2 as make87__messages__ros2_dot_humble_dot_sick__scan__xd_dot_msg_dot_radar__pre__header__device__block__pb2
from make87_messages_ros2.humble.sick_scan_xd.msg import radar_pre_header_encoder_block_pb2 as make87__messages__ros2_dot_humble_dot_sick__scan__xd_dot_msg_dot_radar__pre__header__encoder__block__pb2
from make87_messages_ros2.humble.sick_scan_xd.msg import radar_pre_header_measurement_param1_block_pb2 as make87__messages__ros2_dot_humble_dot_sick__scan__xd_dot_msg_dot_radar__pre__header__measurement__param1__block__pb2
from make87_messages_ros2.humble.sick_scan_xd.msg import radar_pre_header_status_block_pb2 as make87__messages__ros2_dot_humble_dot_sick__scan__xd_dot_msg_dot_radar__pre__header__status__block__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCmake87_messages_ros2/humble/sick_scan_xd/msg/radar_pre_header.proto\x12,make87_messages_ros2.humble.sick_scan_xd.msg\x1a!make87_messages/core/header.proto\x1aPmake87_messages_ros2/humble/sick_scan_xd/msg/radar_pre_header_device_block.proto\x1aQmake87_messages_ros2/humble/sick_scan_xd/msg/radar_pre_header_encoder_block.proto\x1a\\make87_messages_ros2/humble/sick_scan_xd/msg/radar_pre_header_measurement_param1_block.proto\x1aPmake87_messages_ros2/humble/sick_scan_xd/msg/radar_pre_header_status_block.proto\"\xa1\x04\n\x0eRadarPreHeader\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x13\n\x0buiversionno\x18\x02 \x01(\r\x12j\n\x19radarpreheaderdeviceblock\x18\x03 \x01(\x0b\x32G.make87_messages_ros2.humble.sick_scan_xd.msg.RadarPreHeaderDeviceBlock\x12j\n\x19radarpreheaderstatusblock\x18\x04 \x01(\x0b\x32G.make87_messages_ros2.humble.sick_scan_xd.msg.RadarPreHeaderStatusBlock\x12\x80\x01\n$radarpreheadermeasurementparam1block\x18\x05 \x01(\x0b\x32R.make87_messages_ros2.humble.sick_scan_xd.msg.RadarPreHeaderMeasurementParam1Block\x12q\n\x1fradarpreheaderarrayencoderblock\x18\x06 \x03(\x0b\x32H.make87_messages_ros2.humble.sick_scan_xd.msg.RadarPreHeaderEncoderBlockb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.sick_scan_xd.msg.radar_pre_header_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_RADARPREHEADER']._serialized_start=494
  _globals['_RADARPREHEADER']._serialized_end=1039
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from make87_messages_ros2.humble.ublox_ubx_msgs.msg import comms_port_info_pb2 as _comms_port_info_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class UBXMonComms(_message.Message):
    __slots__ = ("header", "ros2_header", "version", "n_ports", "tx_errors", "reserved0", "prot_ids", "ports")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    N_PORTS_FIELD_NUMBER: _ClassVar[int]
    TX_ERRORS_FIELD_NUMBER: _ClassVar[int]
    RESERVED0_FIELD_NUMBER: _ClassVar[int]
    PROT_IDS_FIELD_NUMBER: _ClassVar[int]
    PORTS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    version: int
    n_ports: int
    tx_errors: int
    reserved0: int
    prot_ids: _containers.RepeatedScalarFieldContainer[int]
    ports: _containers.RepeatedCompositeFieldContainer[_comms_port_info_pb2.CommsPortInfo]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., version: _Optional[int] = ..., n_ports: _Optional[int] = ..., tx_errors: _Optional[int] = ..., reserved0: _Optional[int] = ..., prot_ids: _Optional[_Iterable[int]] = ..., ports: _Optional[_Iterable[_Union[_comms_port_info_pb2.CommsPortInfo, _Mapping]]] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class SbgStatusCom(_message.Message):
    __slots__ = ("port_a", "port_b", "port_c", "port_d", "port_e", "port_a_rx", "port_a_tx", "port_b_rx", "port_b_tx", "port_c_rx", "port_c_tx", "port_d_rx", "port_d_tx", "port_e_rx", "port_e_tx", "eth_0", "eth_1", "eth_2", "eth_3", "eth_4", "eth_0_rx", "eth_0_tx", "eth_1_rx", "eth_1_tx", "eth_2_rx", "eth_2_tx", "eth_3_rx", "eth_3_tx", "eth_4_rx", "eth_4_tx", "can_rx", "can_tx", "can_status")
    PORT_A_FIELD_NUMBER: _ClassVar[int]
    PORT_B_FIELD_NUMBER: _ClassVar[int]
    PORT_C_FIELD_NUMBER: _ClassVar[int]
    PORT_D_FIELD_NUMBER: _ClassVar[int]
    PORT_E_FIELD_NUMBER: _ClassVar[int]
    PORT_A_RX_FIELD_NUMBER: _ClassVar[int]
    PORT_A_TX_FIELD_NUMBER: _ClassVar[int]
    PORT_B_RX_FIELD_NUMBER: _ClassVar[int]
    PORT_B_TX_FIELD_NUMBER: _ClassVar[int]
    PORT_C_RX_FIELD_NUMBER: _ClassVar[int]
    PORT_C_TX_FIELD_NUMBER: _ClassVar[int]
    PORT_D_RX_FIELD_NUMBER: _ClassVar[int]
    PORT_D_TX_FIELD_NUMBER: _ClassVar[int]
    PORT_E_RX_FIELD_NUMBER: _ClassVar[int]
    PORT_E_TX_FIELD_NUMBER: _ClassVar[int]
    ETH_0_FIELD_NUMBER: _ClassVar[int]
    ETH_1_FIELD_NUMBER: _ClassVar[int]
    ETH_2_FIELD_NUMBER: _ClassVar[int]
    ETH_3_FIELD_NUMBER: _ClassVar[int]
    ETH_4_FIELD_NUMBER: _ClassVar[int]
    ETH_0_RX_FIELD_NUMBER: _ClassVar[int]
    ETH_0_TX_FIELD_NUMBER: _ClassVar[int]
    ETH_1_RX_FIELD_NUMBER: _ClassVar[int]
    ETH_1_TX_FIELD_NUMBER: _ClassVar[int]
    ETH_2_RX_FIELD_NUMBER: _ClassVar[int]
    ETH_2_TX_FIELD_NUMBER: _ClassVar[int]
    ETH_3_RX_FIELD_NUMBER: _ClassVar[int]
    ETH_3_TX_FIELD_NUMBER: _ClassVar[int]
    ETH_4_RX_FIELD_NUMBER: _ClassVar[int]
    ETH_4_TX_FIELD_NUMBER: _ClassVar[int]
    CAN_RX_FIELD_NUMBER: _ClassVar[int]
    CAN_TX_FIELD_NUMBER: _ClassVar[int]
    CAN_STATUS_FIELD_NUMBER: _ClassVar[int]
    port_a: bool
    port_b: bool
    port_c: bool
    port_d: bool
    port_e: bool
    port_a_rx: bool
    port_a_tx: bool
    port_b_rx: bool
    port_b_tx: bool
    port_c_rx: bool
    port_c_tx: bool
    port_d_rx: bool
    port_d_tx: bool
    port_e_rx: bool
    port_e_tx: bool
    eth_0: bool
    eth_1: bool
    eth_2: bool
    eth_3: bool
    eth_4: bool
    eth_0_rx: bool
    eth_0_tx: bool
    eth_1_rx: bool
    eth_1_tx: bool
    eth_2_rx: bool
    eth_2_tx: bool
    eth_3_rx: bool
    eth_3_tx: bool
    eth_4_rx: bool
    eth_4_tx: bool
    can_rx: bool
    can_tx: bool
    can_status: int
    def __init__(self, port_a: bool = ..., port_b: bool = ..., port_c: bool = ..., port_d: bool = ..., port_e: bool = ..., port_a_rx: bool = ..., port_a_tx: bool = ..., port_b_rx: bool = ..., port_b_tx: bool = ..., port_c_rx: bool = ..., port_c_tx: bool = ..., port_d_rx: bool = ..., port_d_tx: bool = ..., port_e_rx: bool = ..., port_e_tx: bool = ..., eth_0: bool = ..., eth_1: bool = ..., eth_2: bool = ..., eth_3: bool = ..., eth_4: bool = ..., eth_0_rx: bool = ..., eth_0_tx: bool = ..., eth_1_rx: bool = ..., eth_1_tx: bool = ..., eth_2_rx: bool = ..., eth_2_tx: bool = ..., eth_3_rx: bool = ..., eth_3_tx: bool = ..., eth_4_rx: bool = ..., eth_4_tx: bool = ..., can_rx: bool = ..., can_tx: bool = ..., can_status: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.jazzy.rmf_traffic_msgs.msg import convex_shape_context_pb2 as _convex_shape_context_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ShapeContext(_message.Message):
    __slots__ = ("convex_shapes",)
    CONVEX_SHAPES_FIELD_NUMBER: _ClassVar[int]
    convex_shapes: _convex_shape_context_pb2.ConvexShapeContext
    def __init__(self, convex_shapes: _Optional[_Union[_convex_shape_context_pb2.ConvexShapeContext, _Mapping]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SetModeRequest(_message.Message):
    __slots__ = ("header", "base_mode", "custom_mode")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BASE_MODE_FIELD_NUMBER: _ClassVar[int]
    CUSTOM_MODE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    base_mode: int
    custom_mode: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., base_mode: _Optional[int] = ..., custom_mode: _Optional[str] = ...) -> None: ...

class SetModeResponse(_message.Message):
    __slots__ = ("header", "mode_sent")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    MODE_SENT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    mode_sent: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., mode_sent: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rtabmap_msgs/msg/link.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.geometry_msgs.msg import transform_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_transform__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6make87_messages_ros2/jazzy/rtabmap_msgs/msg/link.proto\x12+make87_messages_ros2.jazzy.rtabmap_msgs.msg\x1a<make87_messages_ros2/jazzy/geometry_msgs/msg/transform.proto\"\x95\x01\n\x04Link\x12\x0f\n\x07\x66rom_id\x18\x01 \x01(\x05\x12\r\n\x05to_id\x18\x02 \x01(\x05\x12\x0c\n\x04type\x18\x03 \x01(\x05\x12J\n\ttransform\x18\x04 \x01(\x0b\x32\x37.make87_messages_ros2.jazzy.geometry_msgs.msg.Transform\x12\x13\n\x0binformation\x18\x05 \x03(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rtabmap_msgs.msg.link_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_LINK']._serialized_start=166
  _globals['_LINK']._serialized_end=315
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rc_reason_msgs/srv/silhouette_match_detect_object.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_rolling_dot_builtin__interfaces_dot_msg_dot_time__pb2
from make87_messages_ros2.rolling.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_pose__pb2
from make87_messages_ros2.rolling.rc_common_msgs.msg import return_code_pb2 as make87__messages__ros2_dot_rolling_dot_rc__common__msgs_dot_msg_dot_return__code__pb2
from make87_messages_ros2.rolling.rc_reason_msgs.msg import collision_detection_pb2 as make87__messages__ros2_dot_rolling_dot_rc__reason__msgs_dot_msg_dot_collision__detection__pb2
from make87_messages_ros2.rolling.rc_reason_msgs.msg import grasp_pb2 as make87__messages__ros2_dot_rolling_dot_rc__reason__msgs_dot_msg_dot_grasp__pb2
from make87_messages_ros2.rolling.rc_reason_msgs.msg import load_carrier_pb2 as make87__messages__ros2_dot_rolling_dot_rc__reason__msgs_dot_msg_dot_load__carrier__pb2
from make87_messages_ros2.rolling.rc_reason_msgs.msg import match_pb2 as make87__messages__ros2_dot_rolling_dot_rc__reason__msgs_dot_msg_dot_match__pb2
from make87_messages_ros2.rolling.rc_reason_msgs.msg import silhouette_match_object_pb2 as make87__messages__ros2_dot_rolling_dot_rc__reason__msgs_dot_msg_dot_silhouette__match__object__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nTmake87_messages_ros2/rolling/rc_reason_msgs/srv/silhouette_match_detect_object.proto\x12/make87_messages_ros2.rolling.rc_reason_msgs.srv\x1a>make87_messages_ros2/rolling/builtin_interfaces/msg/time.proto\x1a\x39make87_messages_ros2/rolling/geometry_msgs/msg/pose.proto\x1a\x41make87_messages_ros2/rolling/rc_common_msgs/msg/return_code.proto\x1aImake87_messages_ros2/rolling/rc_reason_msgs/msg/collision_detection.proto\x1a;make87_messages_ros2/rolling/rc_reason_msgs/msg/grasp.proto\x1a\x42make87_messages_ros2/rolling/rc_reason_msgs/msg/load_carrier.proto\x1a;make87_messages_ros2/rolling/rc_reason_msgs/msg/match.proto\x1aMmake87_messages_ros2/rolling/rc_reason_msgs/msg/silhouette_match_object.proto\"\x8f\x03\n\"SilhouetteMatchDetectObjectRequest\x12`\n\x10object_to_detect\x18\x01 \x01(\x0b\x32\x46.make87_messages_ros2.rolling.rc_reason_msgs.msg.SilhouetteMatchObject\x12\x0e\n\x06offset\x18\x02 \x01(\x01\x12\x12\n\npose_frame\x18\x03 \x01(\t\x12H\n\nrobot_pose\x18\x04 \x01(\x0b\x32\x34.make87_messages_ros2.rolling.geometry_msgs.msg.Pose\x12\x17\n\x0fload_carrier_id\x18\x05 \x01(\t\x12`\n\x13\x63ollision_detection\x18\x06 \x01(\x0b\x32\x43.make87_messages_ros2.rolling.rc_reason_msgs.msg.CollisionDetection\x12\x1e\n\x16object_plane_detection\x18\x07 \x01(\x08\"\xbe\x03\n#SilhouetteMatchDetectObjectResponse\x12L\n\ttimestamp\x18\x01 \x01(\x0b\x32\x39.make87_messages_ros2.rolling.builtin_interfaces.msg.Time\x12\x11\n\tobject_id\x18\x02 \x01(\t\x12G\n\x07matches\x18\x03 \x03(\x0b\x32\x36.make87_messages_ros2.rolling.rc_reason_msgs.msg.Match\x12\x46\n\x06grasps\x18\x04 \x03(\x0b\x32\x36.make87_messages_ros2.rolling.rc_reason_msgs.msg.Grasp\x12S\n\rload_carriers\x18\x05 \x03(\x0b\x32<.make87_messages_ros2.rolling.rc_reason_msgs.msg.LoadCarrier\x12P\n\x0breturn_code\x18\x06 \x01(\x0b\x32;.make87_messages_ros2.rolling.rc_common_msgs.msg.ReturnCodeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rc_reason_msgs.srv.silhouette_match_detect_object_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SILHOUETTEMATCHDETECTOBJECTREQUEST']._serialized_start=672
  _globals['_SILHOUETTEMATCHDETECTOBJECTREQUEST']._serialized_end=1071
  _globals['_SILHOUETTEMATCHDETECTOBJECTRESPONSE']._serialized_start=1074
  _globals['_SILHOUETTEMATCHDETECTOBJECTRESPONSE']._serialized_end=1520
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import multi_array_dimension_pb2 as _multi_array_dimension_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MultiArrayLayout(_message.Message):
    __slots__ = ("header", "dim", "data_offset")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    DIM_FIELD_NUMBER: _ClassVar[int]
    DATA_OFFSET_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    dim: _containers.RepeatedCompositeFieldContainer[_multi_array_dimension_pb2.MultiArrayDimension]
    data_offset: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., dim: _Optional[_Iterable[_Union[_multi_array_dimension_pb2.MultiArrayDimension, _Mapping]]] = ..., data_offset: _Optional[int] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class FloatingPointRange(_message.Message):
    __slots__ = ("header", "from_value", "to_value", "step")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    FROM_VALUE_FIELD_NUMBER: _ClassVar[int]
    TO_VALUE_FIELD_NUMBER: _ClassVar[int]
    STEP_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    from_value: float
    to_value: float
    step: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., from_value: _Optional[float] = ..., to_value: _Optional[float] = ..., step: _Optional[float] = ...) -> None: ...
